<a id="options.Path"></a>

## Path

<a id="options.sys"></a>

## sys

<a id="options.AppDirs"></a>

## AppDirs

<a id="options.OPTIONS"></a>

## OPTIONS Objects

```python
class OPTIONS()
```

<a id="options.OPTIONS.APPLICATION_PATH"></a>

#### APPLICATION\_PATH

<a id="options.OPTIONS.app_info_available"></a>

#### app\_info\_available

<a id="options.OPTIONS.app_info"></a>

#### app\_info

<a id="options.OPTIONS.portable"></a>

#### portable

<a id="options.OPTIONS.PORTABLE_SETTINGS_FILE"></a>

#### PORTABLE\_SETTINGS\_FILE

<a id="options.OPTIONS.PORTABLE_FLAG_FILE"></a>

#### PORTABLE\_FLAG\_FILE

